==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/MapleLeafFan.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.ModTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1304;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3489;
import net.minecraft.class_5819;
import net.minecraft.class_8956;
import net.minecraft.class_9886;

public class MapleLeafFan extends SwordItem {
    public static final class_9886 MAPLE_LEAF_FAN = new class_9886(ModTags.BlockTypeTag.EMPTY, 250, 4.0f, 2.5f, 5, class_3489.field_52385);
    public static float POWER = 1.5f;

    public MapleLeafFan(float attackDamage, float attackSpeed, class_1793 settings) {
        super(MAPLE_LEAF_FAN, attackDamage, attackSpeed, settings.method_62832(0.5f));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            class_1676.method_61549((world2, shooter, stack) -> new class_8956(user, world, user.method_19538().method_10216(), user.method_33571().method_10214(), user.method_19538().method_10215()), serverWorld, itemStack, user, 0.0f, POWER, 1.0f);
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), class_3417.field_49045, class_3419.field_15254, 0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f));
            user.method_7259(class_3468.field_15372.method_14956(this));
            if (itemStack.method_7963()) {
                itemStack.method_7970(1, user, class_1304.field_6173);
            }
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

    public class_1676 createEntity(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        class_5819 random = world.method_8409();
        double d = random.method_43385((double) direction.method_10148(), 0.11485000000000001);
        double e = random.method_43385((double) direction.method_10164(), 0.11485000000000001);
        double f = random.method_43385((double) direction.method_10165(), 0.11485000000000001);
        class_243 vec3d = new class_243(d, e, f);
        class_8956 windChargeEntity = new class_8956(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), vec3d);
        windChargeEntity.method_18799(vec3d);
        return windChargeEntity;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/MapleLeafFan.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1304;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3489;
import net.minecraft.class_5819;
import net.minecraft.class_8956;
import net.minecraft.class_9886;
import cc.thonly.reverie_dreams.item.base.SwordItem;

public class MapleLeafFan extends SwordItem {
    public static final class_9886 MAPLE_LEAF_FAN = new class_9886(RDBlockTags.EMPTY, 250, 4.0f, 2.5f, 5, class_3489.field_52385);
    public static float POWER = 1.5f;

    public MapleLeafFan(float attackDamage, float attackSpeed, class_1793 settings) {
        super(MAPLE_LEAF_FAN, attackDamage, attackSpeed, settings.method_62832(0.5f));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            class_1676.method_61549((world2, shooter, stack) -> new class_8956(user, world, user.method_19538().method_10216(), user.method_33571().method_10214(), user.method_19538().method_10215()), serverWorld, itemStack, user, 0.0f, POWER, 1.0f);
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), class_3417.field_49045, class_3419.field_15254, 0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f));
            user.method_7259(class_3468.field_15372.method_14956(this));
            if (itemStack.method_7963()) {
                itemStack.method_7970(1, user, class_1304.field_6173);
            }
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

    public class_1676 createEntity(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        class_5819 random = world.method_8409();
        double d = random.method_43385((double) direction.method_10148(), 0.11485000000000001);
        double e = random.method_43385((double) direction.method_10164(), 0.11485000000000001);
        double f = random.method_43385((double) direction.method_10165(), 0.11485000000000001);
        class_243 vec3d = new class_243(d, e, f);
        class_8956 windChargeEntity = new class_8956(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), vec3d);
        windChargeEntity.method_18799(vec3d);
        return windChargeEntity;
    }
}
